BatchClient class

Client for batch operations

Constructors

BatchClient({required String baseUrl, required TokenStorage tokenStorage, Client? httpClient, Duration timeout = const Duration(seconds: 30), Map<String, String>? headers})
Creates a new BatchClient

Properties

baseUrl String
Base URL of the database service
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
Request timeout duration
final
tokenStorage TokenStorage
Token storage
final

Methods

batchDelete(String collection, List<String> ids) Future<BatchDeleteResult>
Performs batch delete
batchInsert(String collection, List<Map<String, dynamic>> documents) Future<BatchInsertResult>
Performs batch insert
batchMixed(String collection, List<BatchOperation> operations) Future<BatchMixedResult>
Performs batch mixed operations
batchUpdate(String collection, List<BatchUpdateOperation> operations) Future<BatchUpdateResult>
Performs batch update
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited