AuthToken class
Authentication token response
Constructors
Properties
- accessToken → String
-
Access token
final
- expiresIn → int
-
Expiration time in seconds
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- refreshToken → String
-
Refresh token
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenType → String
-
Token type (usually 'Bearer')
final
- user → User?
-
User information
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited