SqlQueryResult class
Result of a SQL query execution
Constructors
-
SqlQueryResult({required List<
Map< data, Map<String, dynamic> >String, dynamic> ? operation}) -
SqlQueryResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
data
→ List<
Map< String, dynamic> > -
The query result data
final
-
first
→ Map<
String, dynamic> ? -
Get first result or null
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether the result is empty
no setter
- isNotEmpty → bool
-
Whether the result has data
no setter
- length → int
-
Number of results
no setter
-
operation
→ Map<
String, dynamic> ? -
The compiled MongoDB operation (for debugging)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited